class MarketData {
// Price formula market ticker variables consist of 3 parts:
// 1. Market name
// 2. Currency pair
// 3. Quote
// E.g. 'bitfinexxmrusdask', where 'bitfinex' is the market name, 'xmrusd' is
// the currency pair, and 'ask' is the quote.

  static const marketsNames = [
    'CoinGecko',
    'Binance',
    'Bitfinex',
    'Bitstamp',
    'Bittrex',
    'Coinbase',
    'CoinbasePro',
    'EXMO',
    'Kraken',
    'Poloniex',
    'UPbit',
  ];

  static const marketsHasQoutes = {
    'CoinGecko': null,
    'Binance': quotes,
    'Bitfinex': quotes,
    'Bitstamp': quotes,
    'Bittrex': quotes,
    'Coinbase': coinbaseQuotes,
    'CoinbasePro': quotes,
    'EXMO': quotes,
    'Kraken': quotes,
    'Poloniex': quotes,
    'UPbit': quotes,
  };

// For most of the markets, currency pairs can be easily split,
// because the right hand currency code is always 3 characters.
// The only exception is coingecko, see below.
  static const marketHasCurrencyPair = {
    'bitfinex': [
      'xmrbtc',
      'xmrusd',
      'btceur',
      'btcgbp',
      'btcjpy',
      'btcusd',
      'bchusd',
      'dashbtc',
      'ethbtc',
      'ltcbtc',
      'xrpbtc',
      'zecbtc',
      'etheur',
      'ethgbp',
      'ethjpy',
      'ethusd',
      'ltcusd',
      'xrpusd',
    ],
    'bittrex': [
      'bchusd',
      'btcusd',
      'ethusd',
      'ltcusd',
      'scusd',
      'xrpusd',
      'bchbtc',
      'bcheth',
      'dogebtc',
      'ethbtc',
      'ltcbtc',
      'ltceth',
      'scbtc',
      'sceth',
      'xrpbtc',
      'xrpeth',
    ],
    // While for the rest of the currency pairs it easy to split them into
    // left and right side, for coingecko pairs, both sides can have any number
    // of characters. That's why they're wrote down here with a dash for easy separation.
    'coingecko': [
      'btc-usd',
      'xmr-btc',
      'xmr-usd',
      'aeon-bch',
      'aeon-btc',
      'aeon-ltc',
      'aeon-usd',
      'bch-btc',
      'bch-ltc',
      'bch-usd',
      'btc-bch',
      'btc-ltc',
      'dash-bch',
      'dash-btc',
      'dash-ltc',
      'dash-usd',
      'doge-bch',
      'doge-btc',
      'doge-ltc',
      'doge-usd',
      'eth-bch',
      'eth-btc',
      'eth-ltc',
      'eth-usd',
      'ltc-bch',
      'ltc-btc',
      'ltc-usd',
      'sc-bch',
      'sc-btc',
      'sc-ltc',
      'sc-usd',
      'xmr-bch',
      'xmr-ltc',
      'xrp-bch',
      'xrp-btc',
      'xrp-ltc',
      'xrp-usd',
      'zec-bch',
      'zec-btc',
      'zec-ltc',
      'zec-usd',
    ],
    'exmo': [
      'xmreur',
      'xmrusd',
      'xmrrub',
      'xmruah',
      'xmreth',
      'xmrbtc',
      'btcusd',
      'btceur',
      'btcrub',
      'btcuah',
      'btcpln',
      'btctry',
      'bchbtc',
      'dashbtc',
      'ethbtc',
      'ltcbtc',
      'zecbtc',
      'xrpbtc',
      'dogebtc',
    ],
    'kraken': [
      'xmrbtc',
      'xmreur',
      'xmrusd',
      'bcheur',
      'bchusd',
      'btccad',
      'btceur',
      'btcgbp',
      'btcjpy',
      'btcusd',
      'bchbtc',
      'dashbtc',
      'dogebtc',
      'ethbtc',
      'ltcbtc',
      'xrpbtc',
      'zecbtc',
      'dasheur',
      'dashusd',
      'ethcad',
      'etheur',
      'ethgbp',
      'ethjpy',
      'ethusd',
      'ltceur',
      'ltcusd',
      'xrpcad',
      'xrpeur',
      'xrpjpy',
      'xrpusd',
      'zeceur',
      'zecusd',
    ],
    'poloniex': [
      'xmrbtc',
      'xmrusd',
      'bchbtc',
      'dashbtc',
      'dogebtc',
      'ethbtc',
      'ltcbtc',
      'scbtc',
      'xrpbtc',
      'zecbtc',
      // 'zeceth',
    ],
    'upbit': [
      'xmrbtc',
      'xmreth',
      'xmrkrw',
      'xmrusd',
      'btckrw',
      'ethkrw',
    ],
    'binance': [
      'xmrbtc',
      'xmreth',
      'bchbtc',
      'ethbtc',
      'dashbtc',
      'dasheth',
      'ltcbtc',
      'ltceth',
      'sceth',
      'scbtc',
      'xrpbtc',
      'xrpeth',
      'zecbtc',
      'zeceth',
    ],
    'bitstamp': [
      'btceur',
      'btcusd',
      'etheur',
      'ethusd',
      'ltceur',
      'ltcusd',
      'xrpeur',
      'xrpusd',
      'xrpbtc',
      'ltcbtc',
      'ethbtc',
      'bchbtc',
      'bcheur',
      'bchusd',
    ],
    'coinbase': [
      'bchusd',
      'btcusd',
      'ethusd',
      'ltcusd',
      'zecusd',
    ],
    'coinbasepro': [
      'bcheur',
      'bchgbp',
      'bchusd',
      'btceur',
      'btcgbp',
      'btcusd',
      'etheur',
      'ethgbp',
      'ethusd',
      'ltceur',
      'ltcgbp',
      'ltcusd',
      'bchbtc',
      'ethbtc',
      'ltcbtc',
    ],
  };

// These are the quotes, the last part of the variable.
  static const quotes = [
    'ask',
    'bid',
    'high',
    'low',
    'open',
    'last',
  ];

// coinbase (not coinbasepro) has different quotes form the rest.
  static const coinbaseQuotes = [
    'buy',
    'sell',
  ];

// Some currency pairs on some markets don't have certain quotes, so those
// shouldn't be displayed. For example, 'exmoxmreuropen' does not exist.
  static const marketLacksQuotes = {
    'exmoxmreur': ['open'],
    'exmoxmrrub': ['open'],
    'exmoxmruah': ['open'],
    'exmoxmreth': ['open'],
    'exmoxmrbtc': ['open'],
    'exmobtcusd': ['open'],
    'exmobtceur': ['open'],
    'exmobtcrub': ['open'],
    'exmobtcuah': ['open'],
    'exmobtcpln': ['open'],
    'exmobtctry': ['open'],
    'exmobchbtc': ['open'],
    'exmodashbtc': ['open'],
    'exmoethbtc': ['open'],
    'exmoltcbtc': ['open'],
    'exmozecbtc': ['open'],
    'exmoxrpbtc': ['open'],
    'exmodogebt': ['open'],
    'exmoxmrusd': ['open'],
    'bittrexxmrusd': ['open'],
    'poloniexxmrusd': ['open'],
    'hitbtcxmrusd': ['open'],
    'bitfinexxmrusd': ['open'],
    'upbitxmrkrw': ['ask', 'bid'],
    'upbitxmrusd': ['ask', 'bid'],
    'upbitxmrbtc': ['ask', 'bid'],
    'upbitxmreth': ['ask', 'bid'],
    'upbitbtckrw': ['ask', 'bid'],
    'upbitethkrw': ['ask', 'bid'],
    'bitfinexbtcusd': ['open'],
    'bitfinexltcusd': ['open'],
    'bitfinexxrpusd': ['open'],
    'bitfinexetheur': ['open'],
    'bitfinexbtceur': ['open'],
    'bitfinexethgbp': ['open'],
    'bitfinexbtcgbp': ['open'],
    'bitfinexethjpy': ['open'],
    'bitfinexbtcjpy': ['open'],
    'bitfinexxmrbtc': ['open'],
    'bitfinexethusd': ['open'],
    'poloniexxmrbtc': ['open'],
    'poloniexltcxmr': ['open'],
    'poloniexzecxmr': ['open'],
    'poloniexdashxmr': ['open'],
    'bittrexxmrbtc': ['open'],
    'bittrexxmreth': ['open'],
    'bittrexbtcusd': ['open'],
    'bittrexxrpusd': ['open'],
    'bittrexzecusd': ['open'],
    'bittrexscusd': ['open'],
    'bittrexethusd': ['open'],
    'bittrexbchusd': ['open'],
    'bittrexltcusd': ['open'],
  };

// For the currency pairs dropdown.
  static const localCurrencies = [
    'usdaed',
    'usdafn',
    'usdall',
    'usdamd',
    'usdang',
    'usdaoa',
    'usdars',
    'usdaud',
    'usdawg',
    'usdazn',
    'usdbam',
    'usdbbd',
    'usdbdt',
    'usdbgn',
    'usdbhd',
    'usdbif',
    'usdbmd',
    'usdbnd',
    'usdbob',
    'usdbrl',
    'usdbsd',
    'usdbtn',
    'usdbwp',
    'usdbyn',
    'usdbzd',
    'usdcad',
    'usdcdf',
    'usdchf',
    'usdclf',
    'usdclp',
    'usdcnh',
    'usdcny',
    'usdcop',
    'usdcrc',
    'usdcuc',
    'usdcup',
    'usdcve',
    'usdczk',
    'usddjf',
    'usddkk',
    'usddop',
    'usddzd',
    'usdegp',
    'usdern',
    'usdetb',
    'usdeur',
    'usdfjd',
    'usdfkp',
    'usdgbp',
    'usdgel',
    'usdggp',
    'usdghs',
    'usdgip',
    'usdgmd',
    'usdgnf',
    'usdgtq',
    'usdgyd',
    'usdhkd',
    'usdhnl',
    'usdhrk',
    'usdhtg',
    'usdhuf',
    'usdidr',
    'usdils',
    'usdimp',
    'usdinr',
    'usdiqd',
    'usdirr',
    'usdisk',
    'usdjep',
    'usdjmd',
    'usdjod',
    'usdjpy',
    'usdkes',
    'usdkgs',
    'usdkhr',
    'usdkmf',
    'usdkpw',
    'usdkrw',
    'usdkwd',
    'usdkyd',
    'usdkzt',
    'usdlak',
    'usdlbp',
    'usdlkr',
    'usdlrd',
    'usdlsl',
    'usdlyd',
    'usdmad',
    'usdmdl',
    'usdmga',
    'usdmkd',
    'usdmmk',
    'usdmnt',
    'usdmop',
    'usdmro',
    'usdmur',
    'usdmvr',
    'usdmwk',
    'usdmxn',
    'usdmyr',
    'usdmzn',
    'usdnad',
    'usdngn',
    'usdnio',
    'usdnok',
    'usdnpr',
    'usdnzd',
    'usdomr',
    'usdpab',
    'usdpen',
    'usdpgk',
    'usdphp',
    'usdpkr',
    'usdpln',
    'usdpyg',
    'usdqar',
    'usdron',
    'usdrsd',
    'usdrub',
    'usdrwf',
    'usdsar',
    'usdsbd',
    'usdscr',
    'usdsdg',
    'usdsek',
    'usdsgd',
    'usdshp',
    'usdsll',
    'usdsos',
    'usdsrd',
    'usdssp',
    'usdstd',
    'usdsvc',
    'usdsyp',
    'usdszl',
    'usdthb',
    'usdtjs',
    'usdtmt',
    'usdtnd',
    'usdtop',
    'usdtry',
    'usdttd',
    'usdtwd',
    'usdtzs',
    'usduah',
    'usdugx',
    'usduyu',
    'usduzs',
    'usdvef',
    'usdvnd',
    'usdvuv',
    'usdwst',
    'usdxaf',
    'usdxag',
    'usdxau',
    'usdxcd',
    'usdxdr',
    'usdxof',
    'usdxpd',
    'usdxpf',
    'usdxpt',
    'usdyer',
    'usdzar',
    'usdzmw',
    'usdzwl',
  ];
}
